<?php
/**
 * Stylite: jdots template
 *
 * @link http://www.stylite.de
 * @package jdots
 * @author Andreas Stöckel <as@stylite.de>
 * @author Ralf Becker <rb@stylite.de>
 * @author Nathan Gray <ng@stylite.de>
 * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
 * @version $Id$
 */

$GLOBALS['egw_info']['template']['jdots']['name']      = 'jdots';
$GLOBALS['egw_info']['template']['jdots']['title']     = 'Stylite';
$GLOBALS['egw_info']['template']['jdots']['version']   = '16.1';

$GLOBALS['egw_info']['template']['jdots']['author'] = array(
	array('name' => 'Andreas Stoeckel', 'email' => 'as@stylite.de'),
	array('name' => 'Ralf Becker', 'email' => 'rb@stylite.de'),
	array('name' => 'Nathan Gray', 'email' => 'ng@stylite.de'),
);
$GLOBALS['egw_info']['template']['jdots']['license'] = 'GPL';
$GLOBALS['egw_info']['template']['jdots']['icon'] = "jdots/images/jdots-logo.png";
$GLOBALS['egw_info']['template']['jdots']['maintainer'] = array(
   array('name' => 'Stylite AG', 'url' => 'http://www.stylite.de/')
);
$GLOBALS['egw_info']['template']['jdots']['description'] = "Stylite is a new jQuery based template set for EGroupware EPL.";
$GLOBALS['egw_info']['template']['jdots']['windowed'] = true;
$GLOBALS['egw_info']['template']['jdots']['icon'] = 'jdots/images/epl.png';

// Dependencies for this template to work
$GLOBALS['egw_info']['template']['pixelegg']['depends'][] = array(
	'appname' => 'api',
	'versions' => Array('16.1')
);
